"""
    parseWorkflow(filePath::String) -> (Dict, Dict)

Parses a workflow configuration file in TOML format to extract the tasks and global settings.

# Arguments
- `filePath::String`: The path to the workflow configuration file in TOML format.

# Returns
- `(Dict, Dict)`: A tuple containing two dictionaries. The first dictionary contains the tasks defined in the workflow file, with each task's properties and configurations. The second dictionary contains global settings that apply to the entire workflow.

# Example
> tasks, globals = parseWorkflow("path/to/workflow.toml")

This function reads the specified TOML file, parsing the defined tasks and global settings into separate dictionaries for further processing in the workflow management system.
"""
function parseWorkflow(filePath::String)
    # Parse the workflow file
    config = TOML.parsefile(filePath)
    globals = config["globals"]
    tasks = config["tasks"]
    return tasks, globals
end
